@@ -10,6 +10,7 @@
 #include <glib/gi18n.h>
 
 #include "gnc-icons.h"
+#include "gnc-filepath-utils.h"
 #include "gnc-gnome-utils.h"
 
 static GtkStockItem items[] =
@@ -49,6 +50,7 @@ static item_file item_files[] =
     { GNC_STOCK_INVOICE_NEW,    "gnc-invoice-new.png",   "gnc-invoice-new-16.png"},
     { GNC_STOCK_INVOICE_EDIT,   "gnc-invoice-edit.png",   "gnc-invoice-edit-16.png"},
     { GNC_STOCK_INVOICE_DUPLICATE, "gnc-invoice-duplicate.png", "gnc-invoice-duplicate-16.png"},
+    { GNC_STOCK_PDF_EXPORT,     "gnc-gnome-pdf-24.png",   "gnc-gnome-pdf-16.png"},
     { 0 },
 };
 
@@ -64,8 +66,8 @@ gnc_add_stock_icon_pair (GtkIconFactory *factory,
     char *fullname1, *fullname2;
 
     /* Find the complete path names for these files */
-    fullname1 = gnc_gnome_locate_pixmap (filename1);
-    fullname2 = gnc_gnome_locate_pixmap (filename2);
+    fullname1 = gnc_filepath_locate_pixmap (filename1);
+    fullname2 = gnc_filepath_locate_pixmap (filename2);
     g_assert (fullname1 && fullname2);
 
     /* Load the pixbufs */
