@@ -32,7 +32,7 @@
 #include "gnc-component-manager.h"
 #include "gncOwner.h"
 #include "gnc-commodity.h"
-#include "gnc-gconf-utils.h"
+#include "gnc-prefs.h"
 #include "gnc-engine.h"
 #include "gnc-event.h"
 #include "gnc-gobject-utils.h"
@@ -108,23 +108,21 @@ typedef struct GncTreeModelOwnerPrivate
 
 /** Tell the GncTreeModelOwner code to update the color that it will
  *  use for negative numbers.  This function will iterate over all
- *  existing models and update their setting from gconf.
+ *  existing models and update their setting.
  *
  *  @internal
  */
 static void
-gnc_tree_model_owner_update_color (GConfEntry *entry, gpointer user_data)
+gnc_tree_model_owner_update_color (gpointer gsettings, gchar *key, gpointer user_data)
 {
     GncTreeModelOwnerPrivate *priv;
     GncTreeModelOwner *model;
-    GConfValue *value;
     gboolean use_red;
 
     g_return_if_fail(GNC_IS_TREE_MODEL_OWNER(user_data));
     model = user_data;
     priv = GNC_TREE_MODEL_OWNER_GET_PRIVATE(model);
-    value = gconf_entry_get_value(entry);
-    use_red = gconf_value_get_bool(value);
+    use_red = gnc_prefs_get_bool(GNC_PREFS_GROUP_GENERAL, GNC_PREF_NEGATIVE_IN_RED);
     priv->negative_color = use_red ? "red" : "black";
 }
 /************************************************************/
@@ -201,7 +199,7 @@ gnc_tree_model_owner_init (GncTreeModelOwner *model)
         model->stamp = g_random_int ();
     }
 
-    red = gnc_gconf_get_bool(GCONF_GENERAL, KEY_NEGATIVE_IN_RED, NULL);
+    red = gnc_prefs_get_bool(GNC_PREFS_GROUP_GENERAL, GNC_PREF_NEGATIVE_IN_RED);
 
     priv = GNC_TREE_MODEL_OWNER_GET_PRIVATE(model);
     priv->book       = NULL;
@@ -209,9 +207,9 @@ gnc_tree_model_owner_init (GncTreeModelOwner *model)
     priv->owner_type = GNC_OWNER_NONE;
     priv->negative_color = red ? "red" : "black";
 
-    gnc_gconf_general_register_cb(KEY_NEGATIVE_IN_RED,
-                                  gnc_tree_model_owner_update_color,
-                                  model);
+    gnc_prefs_register_cb(GNC_PREFS_GROUP_GENERAL, GNC_PREF_NEGATIVE_IN_RED,
+                          gnc_tree_model_owner_update_color,
+                          model);
 
     LEAVE(" ");
 }
@@ -230,10 +228,6 @@ gnc_tree_model_owner_finalize (GObject *object)
     model = GNC_TREE_MODEL_OWNER (object);
     priv = GNC_TREE_MODEL_OWNER_GET_PRIVATE(model);
 
-    gnc_gconf_general_remove_cb(KEY_NEGATIVE_IN_RED,
-                                gnc_tree_model_owner_update_color,
-                                model);
-
     priv->book       = NULL;
     priv->owner_list = NULL;
 
@@ -262,7 +256,7 @@ gnc_tree_model_owner_dispose (GObject *object)
         priv->event_handler_id = 0;
     }
 
-    gnc_gconf_general_remove_cb(KEY_NEGATIVE_IN_RED,
+    gnc_prefs_remove_cb_by_func(GNC_PREFS_GROUP_GENERAL, GNC_PREF_NEGATIVE_IN_RED,
                                 gnc_tree_model_owner_update_color,
                                 model);
 
