@@ -393,7 +393,6 @@ gnc_table_get_gtkrc_bg_color (Table *table, VirtualLocation virt_loc,
                               gboolean *hatching)
 {
     TableGetBGColorHandler bg_color_handler;
-    const char *cell_name;
 
     if (hatching)
         *hatching = FALSE;
@@ -401,8 +400,6 @@ gnc_table_get_gtkrc_bg_color (Table *table, VirtualLocation virt_loc,
     if (!table || !table->model)
         return 0xffffff; /* white */
 
-    cell_name = gnc_table_get_cell_name (table, virt_loc);
-
     bg_color_handler = gnc_table_model_get_bg_color_handler (table->model,
                        "gtkrc");
     if (!bg_color_handler)
@@ -1129,7 +1126,7 @@ gnc_table_enter_update (Table *table,
 
         can_edit = enter (cell, cursor_position, start_selection, end_selection);
 
-        if (safe_strcmp (old_value, cell->value) != 0)
+        if (g_strcmp0 (old_value, cell->value) != 0)
         {
             if (gnc_table_model_read_only (table->model))
             {
@@ -1189,7 +1186,7 @@ gnc_table_leave_update (Table *table, VirtualLocation virt_loc)
 
         leave (cell);
 
-        if (safe_strcmp (old_value, cell->value) != 0)
+        if (g_strcmp0 (old_value, cell->value) != 0)
         {
             if (gnc_table_model_read_only (table->model))
             {
@@ -1295,7 +1292,7 @@ gnc_table_modify_update (Table *table,
         gnc_basic_cell_set_value (cell, newval);
     }
 
-    if (safe_strcmp (old_value, cell->value) != 0)
+    if (g_strcmp0 (old_value, cell->value) != 0)
     {
         changed = TRUE;
         cell->changed = TRUE;
@@ -1365,7 +1362,7 @@ gnc_table_direct_update (Table *table,
     result = cell->direct_update (cell, cursor_position, start_selection,
                                   end_selection, gui_data);
 
-    if (safe_strcmp (old_value, cell->value) != 0)
+    if (g_strcmp0 (old_value, cell->value) != 0)
     {
         if (!gnc_table_confirm_change (table, virt_loc))
         {
@@ -1719,14 +1716,11 @@ gnc_table_traverse_update(Table *table,
                           gncTableTraversalDir dir,
                           VirtualLocation *dest_loc)
 {
-    CellBlock *cb;
     gboolean abort_move;
 
     if ((table == NULL) || (dest_loc == NULL))
         return FALSE;
 
-    cb = table->current_cursor;
-
     ENTER("proposed (%d %d) -> (%d %d)\n",
           virt_loc.vcell_loc.virt_row, virt_loc.vcell_loc.virt_row,
           dest_loc->vcell_loc.virt_row, dest_loc->vcell_loc.virt_col);
