@@ -1055,6 +1055,12 @@ disconnect_popup_toggle_signals (GncItemEdit *item_edit)
     item_edit->popup_toggle.signals_connected = FALSE;
 }
 
+/* Note that g_value_set_object() refs the object, as does
+ * g_object_get(). But g_object_get() only unrefs once when it disgorges
+ * the object, leaving an unbalanced ref, which leaks. So instead of
+ * using g_value_set_object(), use g_value_take_object() which doesn't
+ * ref the object when used in get_property().
+ */
 static void
 gnc_item_edit_get_property (GObject *object,
                             guint param_id,
@@ -1066,10 +1072,10 @@ gnc_item_edit_get_property (GObject *object,
     switch (param_id)
     {
     case PROP_SHEET:
-        g_value_set_object (value, item_edit->sheet);
+        g_value_take_object (value, item_edit->sheet);
         break;
     case PROP_EDITOR:
-        g_value_set_object (value, item_edit->editor);
+        g_value_take_object (value, item_edit->editor);
         break;
     default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
