@@ -164,8 +164,7 @@
 (export gnc:delete-report)
 (export gnc:rename-report)
 (export gnc:find-report-template)
-(export gnc:report-generate-restore-forms)
-(export gnc:report-generate-saved-forms)
+(export gnc:report-serialize)
 (export gnc:report-to-template-new)
 (export gnc:report-to-template-update)
 (export gnc:report-render-html)
