@@ -63,10 +63,10 @@
 (define reportname (N_ "Account Summary"))
 
 (define optname-report-title (N_ "Report Title"))
-(define opthelp-report-title (N_ "Title for this report"))
+(define opthelp-report-title (N_ "Title for this report."))
 
 (define optname-party-name (N_ "Company name"))
-(define opthelp-party-name (N_ "Name of company/individual"))
+(define opthelp-party-name (N_ "Name of company/individual."))
 
 (define optname-date (N_ "Date"))
 ;; FIXME this needs an indent option
@@ -76,47 +76,47 @@
   (N_ "Report on these accounts, if display depth allows."))
 (define optname-depth-limit (N_ "Levels of Subaccounts"))
 (define opthelp-depth-limit
-  (N_ "Maximum number of levels in the account tree displayed"))
+  (N_ "Maximum number of levels in the account tree displayed."))
 (define optname-bottom-behavior (N_ "Depth limit behavior"))
 (define opthelp-bottom-behavior
-  (N_ "How to treat accounts which exceed the specified depth limit (if any)"))
+  (N_ "How to treat accounts which exceed the specified depth limit (if any)."))
 
 (define optname-parent-balance-mode (N_ "Parent account balances"))
 (define optname-parent-total-mode (N_ "Parent account subtotals"))
 
 (define optname-show-zb-accts (N_ "Include accounts with zero total balances"))
 (define opthelp-show-zb-accts
-  (N_ "Include accounts with zero total (recursive) balances in this report"))
+  (N_ "Include accounts with zero total (recursive) balances in this report."))
 (define optname-omit-zb-bals (N_ "Omit zero balance figures"))
 (define opthelp-omit-zb-bals
-  (N_ "Show blank space in place of any zero balances which would be shown"))
+  (N_ "Show blank space in place of any zero balances which would be shown."))
 
 (define optname-use-rules (N_ "Show accounting-style rules"))
 (define opthelp-use-rules
-  (N_ "Use rules beneath columns of added numbers like accountants do"))
+  (N_ "Use rules beneath columns of added numbers like accountants do."))
 
 (define optname-account-links (N_ "Display accounts as hyperlinks"))
-(define opthelp-account-links (N_ "Shows each account in the table as a hyperlink to its register window"))
+(define opthelp-account-links (N_ "Shows each account in the table as a hyperlink to its register window."))
 
 (define optname-show-account-bals (N_ "Account Balance"))
-(define opthelp-show-account-bals (N_ "Show an account's balance"))
+(define opthelp-show-account-bals (N_ "Show an account's balance."))
 (define optname-show-account-code (N_ "Account Code"))
-(define opthelp-show-account-code (N_ "Show an account's account code"))
+(define opthelp-show-account-code (N_ "Show an account's account code."))
 (define optname-show-account-type (N_ "Account Type"))
-(define opthelp-show-account-type (N_ "Show an account's account type"))
+(define opthelp-show-account-type (N_ "Show an account's account type."))
 (define optname-show-account-desc (N_ "Account Description"))
-(define opthelp-show-account-desc (N_ "Show an account's description"))
+(define opthelp-show-account-desc (N_ "Show an account's description."))
 (define optname-show-account-notes (N_ "Account Notes"))
-(define opthelp-show-account-notes (N_ "Show an account's notes"))
+(define opthelp-show-account-notes (N_ "Show an account's notes."))
 
 (define pagename-commodities (N_ "Commodities"))
 (define optname-report-commodity (N_ "Report's currency"))
 (define optname-price-source (N_ "Price Source"))
 (define optname-show-foreign (N_ "Show Foreign Currencies"))
 (define opthelp-show-foreign
-  (N_ "Display any foreign currency amount in an account"))
+  (N_ "Display any foreign currency amount in an account."))
 (define optname-show-rates (N_ "Show Exchange Rates"))
-(define opthelp-show-rates (N_ "Show the exchange rates used"))
+(define opthelp-show-rates (N_ "Show the exchange rates used."))
 
 ;; FIXME: add more account metadata options!
 
@@ -170,13 +170,13 @@
       'summarize
       (list (vector 'summarize
 		    (N_ "Recursive Balance")
-		    (N_ "Show the total balance, including balances in subaccounts, of any account at the depth limit"))
+		    (N_ "Show the total balance, including balances in subaccounts, of any account at the depth limit."))
 	    (vector 'flatten
 		    (N_ "Raise Accounts")
-		    (N_ "Shows accounts deeper than the depth limit at the depth limit"))
+		    (N_ "Shows accounts deeper than the depth limit at the depth limit."))
 	    (vector 'truncate
 		    (N_ "Omit Accounts")
-		    (N_ "Disregard completely any accounts deeper than the depth limit"))
+		    (N_ "Disregard completely any accounts deeper than the depth limit."))
 	    )
       )
      )
